@@ -50,7 +50,7 @@ class CarsDataset(Dataset):
         }
 
     def __len__(self):
-        return self.v1.shape[0]
+        return len(self.dataset["view_1"])
 
     def _check_raw_exists(self) -> bool:
         return os.path.exists(
